GUMSTIX_IP=192.168.50.3
HEALTHNET_ROOT=/root/healthnet
GUMSTIX_HOST=root@$GUMSTIX_IP

echo "Verifying that gumstix is present at $GUMSTIX_IP..."

if ping -t 2 -c 1 $GUMSTIX_IP > /dev/null ; then
    echo 'Gumstix is connected.'
else
    echo 'Error: gumstix is not connected.'
    exit 1
fi

# Note: -p creates all needed parent directories.
echo "Creating directory structure..."
if ssh $GUMSTIX_HOST mkdir -p $HEALTHNET_ROOT/data/backup $HEALTHNET_ROOT/bin $HEALTHNET_ROOT/gpsd $HEALTHNET_ROOT/common $HEALTHNET_ROOT/aggregator $HEALTHNET_ROOT/noded $HEALTHNET_ROOT/serialecho $HEALTHNET_ROOT/cleardb $HEALTHNET_ROOT/log ; then
    echo 'Directory structure created.'
else
    echo 'Gumstix not accepting SSH connections.'
    exit 1
fi

echo "Copying run_all.sh..."
scp -q run_all.sh Makefile $GUMSTIX_HOST:$HEALTHNET_ROOT
#echo "Copying gumdataserver..."
#scp -q gumdataserver/Makefile gumdataserver/gumdataserver.c $GUMSTIX_HOST:$HEALTHNET_ROOT/gumdataserver
echo "Copying gpsd..."
scp -q gpsd/Makefile gpsd/gpsd.c gpsd/parse_gps.c gpsd/parse_gps.h $GUMSTIX_HOST:$HEALTHNET_ROOT/gpsd
echo "Copying aggregator..."
scp -q aggregator/Makefile aggregator/aggregator.c $GUMSTIX_HOST:$HEALTHNET_ROOT/aggregator
echo "Copying common..."
scp -q common/Makefile common/healthnet_gumstix.h common/serial.c common/serial.h common/server.c common/server.h $GUMSTIX_HOST:$HEALTHNET_ROOT/common
echo "Copying noded..."
scp -q noded/noded.c noded/Makefile $GUMSTIX_HOST:$HEALTHNET_ROOT/noded
#echo "Copying noded..."
#scp -q screen/sspscreen.h screen/Makefile screen/sspscreen.c $GUMSTIX_HOST:$HEALTHNET_ROOT/screen
#echo "Copying avr code..."
#scp -qr ../avr $GUMSTIX_HOST:$HEALTHNET_ROOT
echo "Copying serial echo..."
scp -q serialecho/serialecho.c serialecho/Makefile $GUMSTIX_HOST:$HEALTHNET_ROOT/serialecho
echo "Copying cleardb..."
scp -q cleardb/cleardb.c cleardb/Makefile $GUMSTIX_HOST:$HEALTHNET_ROOT/cleardb

echo "Running make"
ssh $GUMSTIX_HOST make -C /root/healthnet

echo "Copying startup script..."
scp -q startup_script.sh $GUMSTIX_HOST:$HEALTHNET_ROOT
ssh $GUMSTIX_HOST cp $HEALTHNET_ROOT/startup_script.sh /etc/init.d/S40startup_script.sh

# Set up empty sqlite database.
echo 'Backing up old database...'
ssh $GUMSTIX_HOST cp $HEALTHNET_ROOT/data/bodydata.db $HEALTHNET_ROOT/data/backup/bodydata.db.$(date +%Y-%h-%d-%s)
ssh $GUMSTIX_HOST cp $HEALTHNET_ROOT/data/ekgdata.db $HEALTHNET_ROOT/data/backup/ekgdata.db.$(date +%Y-%h-%d-%s)
echo "Creating body database for gumstix..."
cd ../common/db; ./create_db.sh /tmp/bodydata.db; ./create_db.sh /tmp/ekgdata.db
echo 'Copying new databases to gumstix...'
scp -q /tmp/bodydata.db /tmp/ekgdata.db $GUMSTIX_HOST:$HEALTHNET_ROOT/data

echo '\nSensorServer ready!'
