/* This file has been prepared for Doxygen automatic documentation generation.*/
/*! \file *********************************************************************
 *
 * \brief This files contains the different build options for the extended 
 *        wireless uart example.
 *
 * \par Application note:
 *      AVR2001: AT86RF230 Software Programmer's Guide
 *
 * \par Documentation
 *      For comprehensive code documentation, supported compilers, compiler 
 *      settings and supported devices see readme.html
 *
 * \author
 *      Atmel Corporation: http://www.atmel.com \n
 *      Support email: avr@atmel.com
 * 
 * $Name$
 * $Revision: 613 $
 * $RCSfile$
 * $Date: 2006-04-07 14:40:07 +0200 (fr, 07 apr 2006) $  \n
 *
 * Copyright (c) 2006, Atmel Corporation All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * 3. The name of ATMEL may not be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY ATMEL ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE EXPRESSLY AND
 * SPECIFICALLY DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ******************************************************************************/
#ifndef CONFIG_UART_EXTENDED
#define CONFIG_UART_EXTENDED

#define OPERATING_CHANNEL ( 0xC ) // !< Channel to transmit on. Must be between 11 and 26!
#define PAN_ID            ( 0x3332 ) //!< System PAN ID.

//Make sure that the two nodes are programmed with different short address 
//(SHORT_ADDRESS) and destination address (DEST_ADDRESS). Do this by commenting
//out one of the sections below. First compile for Node1 and then for Node2.

//Node1
#define SHORT_ADDRESS_NODE1 ( 0xBAAD ) //!< Short Addres for node 1 of the link.

//Node2
#define SHORT_ADDRESS_NODE2 ( 0x0 ) //!< Short Addres for node 2 of the link.

/*Compile and program once for each of these options.*/
#define NODE1
//#define NODE2

#ifdef NODE1
#define SHORT_ADDRESS ( SHORT_ADDRESS_NODE1 )
#define DEST_ADDRESS  ( SHORT_ADDRESS_NODE2 )
#else
#define SHORT_ADDRESS ( SHORT_ADDRESS_NODE2 )
#define DEST_ADDRESS  ( SHORT_ADDRESS_NODE1 )
#endif

/*Chose one of these options according to the kit you want to use.*/
//#define STK541
#define RZ502

#define COM_RX_BUFFER_SIZE ( 118 ) //DO NOT ALTER!!!
#define RX_POOL_SIZE       ( 4 ) //MUST BE GREATER THAN ZERO.
#endif
/*EOF*/
