/**
 * @file
 * Definitions for the transceiver chip AT86RF230.
 *
 * $Id: wpan_at86rf230.h,v 1.6 2007/04/26 15:41:08 awachtle Exp $
 * $Revision: 1.6 $
 * $Date: 2007/04/26 15:41:08 $
 *
 */
/*
 * Copyright (c) 2006, Atmel Corporation All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * 3. The name of ATMEL may not be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY ATMEL ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE EXPRESSLY AND
 * SPECIFICALLY DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
/**
 *  \author
 *      Atmel Corporation: http://www.atmel.com
 *      Support email: avr@atmel.com
 */

#ifndef WPAN_AT86RF230_H
#define WPAN_AT86RF230_H

/* === Includes ============================================================== */
#ifndef HAVE_REGISTER_MAP
#include "phy230_registermap.h"
#endif
/* === Externals ============================================================= */

/* === Types ================================================================= */
#ifndef HAVE_RADIO_TYPES
 /** abstract type of a radio chip register (8 or 32 bits) */
 typedef uint8_t radio_reg_t;
 /** abstract type of a radio chip SRAM address (currently 8 bits) */
 typedef uint8_t radio_ram_t;
# define HAVE_RADIO_TYPES (1)
#endif
/* === Macros ================================================================ */

/* The following Macros define the Interrupt Status */

/** \brief signals low battery
 * @ingroup apiHalPHY230Const
 */
#   define TRX_IRQ_BAT_LOW             (0x80)
/** \brief signals a FIFO underrun
 * @ingroup apiHalPHY230Const
 */
#   define TRX_IRQ_TRX_UR              (0x40)
/** \brief reserved
 * @ingroup apiHalPHY230Const
 */
#   define TRX_IRQ_5                   (0x20)
/** \brief reserved
 * @ingroup apiHalPHY230Const
 */
#   define TRX_IRQ_4                   (0x10)
/** \brief signals end of frames (transmit and receive)
 * @ingroup apiHalPHY230Const
 */
#   define TRX_IRQ_TRX_END             (0x08)
/** \brief signals begin of a receiving frame
 * @ingroup apiHalPHY230Const
 */
#   define TRX_IRQ_RX_START            (0x04)
/** \brief signals an unlocked PLL
 * @ingroup apiHalPHY230Const
 */
#   define TRX_IRQ_PLL_UNLOCK          (0x02)
/** \brief PLL goes to lock-state
 * @ingroup apiHalPHY230Const
 */
#   define TRX_IRQ_PLL_LOCK            (0x01)

/** \brief RF230 FIFO size
 * @ingroup apiHalPHY230Const
 */
#   define RF230_RAM_SIZE              (0x80)

/** TX_ARET status tx success
 * @ingroup apiHalPHY230Const
 */
#define TRAC_SUCCESS   (0)
/** TX_ARET status channel access failes
 * @ingroup apiHalPHY230Const
 */
#define TRAC_CHANNEL_ACCESS_FAILURE (3)
/** TX_ARET status no ack received @ingroup apiHalPHY230
 * @ingroup apiHalPHY230Const
 */
#define TRAC_NO_ACK (5)


/**
 * Minimum RSSI sensitivity in dBm.
 * @ingroup apiHalPHY230Const
 */
#define RSSI_BASE_VAL  (-91)

/* === Prototypes ============================================================ */

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
} /* extern "C" */
#endif

#endif /* WPAN_AT86RF230 */
/* EOF */
