#! /usr/bin/python

'''
Eugene Marinelli
4/24/08
Healthnet - PC-side data uploader.  Uses scp to copy sqlite database file, then dumps that data into a local db.
'''

from optparse import OptionParser
import os
import sqlite3
import sys

TMPDB_FILENAME = "/tmp/bodydata_tmp.db"
EKGDB_FILENAME = "/tmp/ekgdata_tmp.db"
STATS_TABLE = "data_collection"
EKG_TABLE = "EKG_Data"

def row_to_string(row): # omfg python
    s = ""
    for e in row:
        if type(e) == unicode:
            s = s + '"' + str(e) + '",'
        else:
            if e == None:
                s = s + "NULL,"
            else:
                s = s + str(e) + ","

    s = "(" + s[0:-1] + ")"

    return s

def main():
    parser = OptionParser()
    parser.add_option("-d", "--database", dest="db", help="Output database file", type="string")
    parser.add_option("-i", "--gumstix_ip", dest="ip", help="Gumstix IP address", default="192.168.50.3",
                      type="string")

    (options, args) = parser.parse_args()

    if options.db == None:
        parser.error("No database filename provided.")
        exit(1)

    upload_db(options.db, options.ip)

def upload_db(local_db_filename, sensorserver_ip):
    print "Copying database from SensorServer..."

    ss_host = "root@%s" % sensorserver_ip
    hn_root = "%s:/root/healthnet" % ss_host

    scp_cmd = "scp %s/data/bodydata.db %s" % (hn_root, TMPDB_FILENAME)
    os.system(scp_cmd)
    scp_cmd = "scp %s/data/ekgdata.db %s" % (hn_root, EKGDB_FILENAME)
    os.system(scp_cmd)

    print "Database copied.  Dumping entries into local database..."

    # Load data from uploaded file and save entries in local db.
    tmpdb_conn = sqlite3.connect(TMPDB_FILENAME)
    tmpcursor = tmpdb_conn.cursor()

    db_conn = sqlite3.connect(local_db_filename)
    dbcursor = db_conn.cursor()

    # Copy body stats
    print "Copying body stats..."
    tmpcursor.execute("select * from %s" % STATS_TABLE)
    for row in tmpcursor:
        db_conn.execute("insert into data_collection values%s" % row_to_string(row))
    db_conn.commit()

    tmpdb_conn.close()

    # Copy EKG stats
    ekgdb_conn = sqlite3.connect(EKGDB_FILENAME)
    ekgcursor = ekgdb_conn.cursor()

    print "Copying EKG stats..."
    ekgcursor.execute("select * from %s" % EKG_TABLE)
    for row in ekgcursor:
        db_conn.execute("insert into ekg_data values%s" % row_to_string(row))
    db_conn.commit()

    db_conn.close()
    ekgdb_conn.close()

    print "Clearing database on gumstix..."

    cleardb_cmd = "ssh %s /root/healthnet/bin/cleardb /root/healthnet/data/bodydata.db" % ss_host
    os.system(cleardb_cmd)
    cleardb_cmd = "ssh %s /root/healthnet/bin/cleardb /root/healthnet/data/ekgdata.db" % ss_host
    os.system(cleardb_cmd)

    print "Done."

if __name__ == "__main__":
    main()
