#! /usr/bin/python

'''
Eugene Marinelli
3/2/08
Healthnet - PC-side data uploader.
'''

import socket
import sys
import sqlite3
import time
from optparse import OptionParser

def format_data(d):
  return map(int, d.split(","))

def main():
  parser = OptionParser()
  parser.add_option("-p", "--port", dest="p", help="Port number", default=10123, type="int")
  parser.add_option("-d", "--database", dest="db", help="Output database file", type="string")
  parser.add_option("-t", "--time", action="store_true", dest="t", default=False,
                    help="Keep track of times when packets are received.")
  parser.add_option("-i", "--gumstix_ip", dest="ip", help="Gumstix IP address", default="192.168.50.3", type="string")

  (options, args) = parser.parse_args()

  if options.db == None:
    parser.error("No database filename provided.")
    exit(1)

  SENSORSERVER_PORT = options.p
  DB_FILENAME = options.db
  KEEP_TIME = options.t
  SENSORSERVER_IP = options.ip

  if KEEP_TIME:
    print "Keeping track of entry receive times."
    start_time = time.time()
    time_table = {}
    time_data_frame_count = 0
    time_table[time_data_frame_count] = 0.0

  # Connect to sensor server.
  print 'Connecting to %s on port %d...' % (SENSORSERVER_IP, SENSORSERVER_PORT)
  s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
  s.connect((SENSORSERVER_IP, SENSORSERVER_PORT))

  print 'Receiving data from %s...' % (SENSORSERVER_IP)

  data_acc = ''
  data = s.recv(1024)
  while data != '':
    if KEEP_TIME:
      time_data_frame_count += 1
      time_table[time_data_frame_count] = time.time() - start_time

    data_acc += data
    data = s.recv(1024)

  print 'Data uploaded.'

  elts = data_acc.split(";")
  elts = filter(lambda e: e != '', elts)
  elts = map(format_data, elts)

  data_array = []
  for e in elts:
    if len(e) > 1:
      data_array.append(e)

  print len(data_array), "entries received."

  s.close()

  # Save data in sqlite db.
  print "Saving records to database %s..." % DB_FILENAME

  sql_conn = sqlite3.connect(DB_FILENAME)
  c = sql_conn.cursor()

  for d in data_array:
    if len(d) > 1:
      num_str = "insert into bodystats values("
      for i in d[0 : len(d)-1]: # Exclude last element.
        num_str += ("%d," % i)

      num_str += ("%d" % d[-1]) + ")"

      # TODO emarinel - decouple this from stats schema
      c.execute(num_str)
      sql_conn.commit()

  c.close()

  print "Data saved."

  if KEEP_TIME:
    print "Time table:"
    for d,t in time_table.items():
      print "%d,%f" % (d,t)

if __name__ == "__main__":
  main()
